# copyright 2016-2017 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr -- mailto:contact@logilab.fr
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
"""THIS FILE IS GENERATED FROM SEDA 2.0 XSD FILES, DO NOT EDIT"""

from cubicweb.web import formwidgets as fw
from cubicweb.web.views import uicfg

ives = uicfg.indexview_etype_section
ives['SEDALastModified'] = 'subobject'
ives['SEDADataObjectVersion'] = 'subobject'
ives['SEDAReplaces'] = 'subobject'
ives['SEDAAltReferencesArchiveUnitRefId'] = 'subobject'
ives['SEDACreatingOsVersion'] = 'subobject'
ives['SEDARepositoryArchiveUnitPID'] = 'subobject'
ives['SEDAKeywordReference'] = 'subobject'
ives['SEDASignature'] = 'subobject'
ives['SEDASpatial'] = 'subobject'
ives['SEDAMessageDigestAlgorithmCodeListVersion'] = 'subobject'
ives['SEDAFormatLitteral'] = 'subobject'
ives['SEDADateCreatedByApplication'] = 'subobject'
ives['SEDAFormatId'] = 'subobject'
ives['SEDAOriginatingAgencyArchiveUnitIdentifier'] = 'subobject'
ives['SEDAAltClassificationRulePreventInheritance'] = 'subobject'
ives['SEDAGpsAltitudeRef'] = 'subobject'
ives['SEDAAltIsVersionOfArchiveUnitRefId'] = 'subobject'
ives['SEDAArchiveUnitRefId'] = 'subobject'
ives['SEDAHeight'] = 'subobject'
ives['SEDASentDate'] = 'subobject'
ives['SEDAGpsLongitude'] = 'subobject'
ives['SEDALanguage'] = 'subobject'
ives['SEDAClassificationReassessingDate'] = 'subobject'
ives['SEDAGpsLatitude'] = 'subobject'
ives['SEDADiameter'] = 'subobject'
ives['SEDACustodialHistoryFile'] = 'subobject'
ives['SEDAStatus'] = 'subobject'
ives['SEDASeqStorageRuleRule'] = 'subobject'
ives['SEDAAltReplacesArchiveUnitRefId'] = 'subobject'
ives['SEDASystemId'] = 'subobject'
ives['SEDAEventType'] = 'subobject'
ives['SEDAIsPartOf'] = 'subobject'
ives['SEDAPreventInheritance'] = 'subobject'
ives['SEDAAltArchiveUnitArchiveUnitRefId'] = 'subobject'
ives['SEDAwhen'] = 'subobject'
ives['SEDAKeywordType'] = 'subobject'
ives['SEDAGpsAltitude'] = 'subobject'
ives['SEDAIsVersionOf'] = 'subobject'
ives['SEDAArchivalAgreement'] = 'subobject'
ives['SEDAFileFormatCodeListVersion'] = 'subobject'
ives['SEDASeqAltArchiveUnitArchiveUnitRefIdManagement'] = 'subobject'
ives['SEDATitle'] = 'subobject'
ives['SEDAGpsDateStamp'] = 'subobject'
ives['SEDAEncoding'] = 'subobject'
ives['SEDACreatingApplicationVersion'] = 'subobject'
ives['SEDATransactedDate'] = 'subobject'
ives['SEDARepositoryObjectPID'] = 'subobject'
ives['SEDARegisteredDate'] = 'subobject'
ives['SEDANeedAuthorization'] = 'subobject'
ives['SEDAEvent'] = 'subobject'
ives['SEDARelationship'] = 'subobject'
ives['SEDATag'] = 'subobject'
ives['SEDAAltStorageRulePreventInheritance'] = 'subobject'
ives['SEDAWriter'] = 'subobject'
ives['SEDAAccessRuleCodeListVersion'] = 'subobject'
ives['SEDAAcquisitionInformationCodeListVersion'] = 'subobject'
ives['SEDALegalStatus'] = 'subobject'
ives['SEDADisseminationRule'] = 'subobject'
ives['SEDAAddressee'] = 'subobject'
ives['SEDAReferences'] = 'subobject'
ives['SEDADataObjectVersionCodeListVersion'] = 'subobject'
ives['SEDAAuthorizedAgent'] = 'subobject'
ives['SEDASubmissionAgencyIdentifier'] = 'subobject'
ives['SEDACreatingApplicationName'] = 'subobject'
ives['SEDAKeyword'] = 'subobject'
ives['SEDADescription'] = 'subobject'
ives['SEDAFilePlanPosition'] = 'subobject'
ives['SEDAArchiveUnit'] = 'subobject'
ives['SEDASeqAccessRuleRule'] = 'subobject'
ives['SEDARefNonRuleId'] = 'subobject'
ives['SEDAWidth'] = 'subobject'
ives['SEDAClassificationRuleCodeListVersion'] = 'subobject'
ives['SEDARequires'] = 'subobject'
ives['SEDAOriginatingSystemId'] = 'subobject'
ives['SEDAVersion'] = 'subobject'
ives['SEDAGpsLongitudeRef'] = 'subobject'
ives['SEDASource'] = 'subobject'
ives['SEDAAcquisitionInformation'] = 'subobject'
ives['SEDAEndDate'] = 'subobject'
ives['SEDACreatingOs'] = 'subobject'
ives['SEDAAltRequiresArchiveUnitRefId'] = 'subobject'
ives['SEDAWeight'] = 'subobject'
ives['SEDAType'] = 'subobject'
ives['SEDADocumentType'] = 'subobject'
ives['SEDAGpsLatitudeRef'] = 'subobject'
ives['SEDAComment'] = 'subobject'
ives['SEDADescriptionLanguage'] = 'subobject'
ives['SEDAAccessRule'] = 'subobject'
ives['SEDACompressionAlgorithmCodeListVersion'] = 'subobject'
ives['SEDATemporal'] = 'subobject'
ives['SEDAPhysicalDataObject'] = 'subobject'
ives['SEDAStartDate'] = 'subobject'
ives['SEDAThickness'] = 'subobject'
ives['SEDAAltAppraisalRulePreventInheritance'] = 'subobject'
ives['SEDASeqAppraisalRuleRule'] = 'subobject'
ives['SEDAEncodingCodeListVersion'] = 'subobject'
ives['SEDATransferRequestReplyIdentifier'] = 'subobject'
ives['SEDARelationshipCodeListVersion'] = 'subobject'
ives['SEDACompressed'] = 'subobject'
ives['SEDAUri'] = 'subobject'
ives['SEDAEventDetail'] = 'subobject'
ives['SEDAAppraisalRule'] = 'subobject'
ives['SEDAReuseRuleCodeListVersion'] = 'subobject'
ives['SEDAAcquiredDate'] = 'subobject'
ives['SEDASeqReuseRuleRule'] = 'subobject'
ives['SEDAServiceLevel'] = 'subobject'
ives['SEDANumberOfPage'] = 'subobject'
ives['SEDAAppraisalRuleCodeListVersion'] = 'subobject'
ives['SEDAJuridictional'] = 'subobject'
ives['SEDAReuseRule'] = 'subobject'
ives['SEDACustodialHistoryItem'] = 'subobject'
ives['SEDATransferringAgencyArchiveUnitIdentifier'] = 'subobject'
ives['SEDALength'] = 'subobject'
ives['SEDAArchivalAgencyArchiveUnitIdentifier'] = 'subobject'
ives['SEDAOriginatingAgency'] = 'subobject'
ives['SEDACreatedDate'] = 'subobject'
ives['SEDADisseminationRuleCodeListVersion'] = 'subobject'
ives['SEDAAltAccessRulePreventInheritance'] = 'subobject'
ives['SEDADepth'] = 'subobject'
ives['SEDAEventIdentifier'] = 'subobject'
ives['SEDAAltBinaryDataObjectAttachment'] = 'subobject'
ives['SEDANeedReassessingAuthorization'] = 'subobject'
ives['SEDAStorageRule'] = 'subobject'
ives['SEDABinaryDataObject'] = 'subobject'
ives['SEDAGpsVersionID'] = 'subobject'
ives['SEDASeqDisseminationRuleRule'] = 'subobject'
ives['SEDAAltReuseRulePreventInheritance'] = 'subobject'
ives['SEDAClassificationRule'] = 'subobject'
ives['SEDARelatedTransferReference'] = 'subobject'
ives['SEDAAttachment'] = 'subobject'
ives['SEDASeqClassificationRuleRule'] = 'subobject'
ives['SEDAStorageRuleCodeListVersion'] = 'subobject'
ives['SEDASubmissionAgency'] = 'subobject'
ives['SEDAMimeType'] = 'subobject'
ives['SEDAReceivedDate'] = 'subobject'
ives['SEDAOriginatingAgencyIdentifier'] = 'subobject'
ives['SEDAMimeTypeCodeListVersion'] = 'subobject'
ives['SEDARecipient'] = 'subobject'
ives['SEDADataObjectReference'] = 'subobject'
ives['SEDAAltDisseminationRulePreventInheritance'] = 'subobject'
ives['SEDAShape'] = 'subobject'
ives['SEDAAltIsPartOfArchiveUnitRefId'] = 'subobject'


abaa = uicfg.actionbox_appearsin_addmenu
abaa.tag_subject_of(('*', 'seda_comment', '*'), False)
abaa.tag_object_of(('*', 'seda_comment', '*'), False)
abaa.tag_subject_of(('*', 'seda_signature', '*'), False)
abaa.tag_object_of(('*', 'seda_signature', '*'), False)
abaa.tag_subject_of(('*', 'seda_archival_agreement', '*'), False)
abaa.tag_object_of(('*', 'seda_archival_agreement', '*'), False)
abaa.tag_subject_of(('*', 'seda_related_transfer_reference', '*'), False)
abaa.tag_object_of(('*', 'seda_related_transfer_reference', '*'), False)
abaa.tag_subject_of(('*', 'seda_transfer_request_reply_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_transfer_request_reply_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_archival_agency', '*'), False)
abaa.tag_subject_of(('*', 'seda_archival_agency', '*'), False)
abaa.tag_object_of(('*', 'seda_transferring_agency', '*'), False)
abaa.tag_subject_of(('*', 'seda_transferring_agency', '*'), False)
abaa.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_mime_type_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_mime_type_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_mime_type_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_mime_type_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_encoding_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_encoding_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_encoding_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_encoding_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_file_format_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_file_format_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_file_format_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_file_format_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_data_object_version_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_data_object_version_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_data_object_version_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_data_object_version_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_storage_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_storage_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_storage_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_storage_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_access_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_access_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_access_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_access_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_classification_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_classification_rule_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_classification_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_classification_rule_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_relationship_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_relationship_code_list_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_relationship_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_relationship_code_list_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_binary_data_object', '*'), False)
abaa.tag_object_of(('*', 'seda_binary_data_object', '*'), False)
abaa.tag_subject_of(('*', 'seda_physical_data_object', '*'), False)
abaa.tag_object_of(('*', 'seda_physical_data_object', '*'), False)
abaa.tag_subject_of(('*', 'seda_relationship', '*'), False)
abaa.tag_object_of(('*', 'seda_relationship', '*'), False)
abaa.tag_subject_of(('*', 'seda_data_object_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_data_object_version_from', '*'), False)
abaa.tag_object_of(('*', 'seda_data_object_version_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_data_object_version_to', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_binary_data_object_attachment', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_binary_data_object_attachment', '*'), False)
abaa.tag_subject_of(('*', 'seda_compressed', '*'), False)
abaa.tag_object_of(('*', 'seda_compressed', '*'), False)
abaa.tag_subject_of(('*', 'seda_archive_unit', '*'), False)
abaa.tag_object_of(('*', 'seda_archive_unit', '*'), False)
abaa.tag_subject_of(('*', 'seda_service_level', '*'), False)
abaa.tag_object_of(('*', 'seda_service_level', '*'), False)
abaa.tag_subject_of(('*', 'seda_acquisition_information_from', '*'), False)
abaa.tag_object_of(('*', 'seda_acquisition_information_from', '*'), False)
abaa.tag_object_of(('*', 'seda_acquisition_information_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_acquisition_information_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_legal_status_from', '*'), False)
abaa.tag_object_of(('*', 'seda_legal_status_from', '*'), False)
abaa.tag_object_of(('*', 'seda_legal_status_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_legal_status_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_originating_agency_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_originating_agency_identifier', '*'), False)
abaa.tag_subject_of(('*', 'seda_submission_agency_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_submission_agency_identifier', '*'), False)
abaa.tag_subject_of(('*', 'seda_storage_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_storage_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_appraisal_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_appraisal_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_access_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_access_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_dissemination_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_dissemination_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_reuse_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_reuse_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_classification_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_classification_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_need_authorization', '*'), False)
abaa.tag_object_of(('*', 'seda_need_authorization', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_archive_unit_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_archive_unit_archive_unit_ref_id', '*'), False)
abaa.tag_object_of(('*', 'seda_type_relationship', '*'), False)
abaa.tag_subject_of(('*', 'seda_type_relationship', '*'), False)
abaa.tag_object_of(('*', 'seda_target', '*'), False)
abaa.tag_subject_of(('*', 'seda_target', '*'), False)
abaa.tag_subject_of(('*', 'seda_attachment', '*'), False)
abaa.tag_object_of(('*', 'seda_attachment', '*'), False)
abaa.tag_subject_of(('*', 'seda_uri', '*'), False)
abaa.tag_object_of(('*', 'seda_uri', '*'), False)
abaa.tag_object_of(('*', 'seda_algorithm', '*'), False)
abaa.tag_subject_of(('*', 'seda_algorithm', '*'), False)
abaa.tag_subject_of(('*', 'seda_format_litteral', '*'), False)
abaa.tag_object_of(('*', 'seda_format_litteral', '*'), False)
abaa.tag_subject_of(('*', 'seda_mime_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_mime_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_mime_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_mime_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_format_id_from', '*'), False)
abaa.tag_object_of(('*', 'seda_format_id_from', '*'), False)
abaa.tag_object_of(('*', 'seda_format_id_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_format_id_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_encoding_from', '*'), False)
abaa.tag_object_of(('*', 'seda_encoding_from', '*'), False)
abaa.tag_object_of(('*', 'seda_encoding_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_encoding_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_creating_application_name', '*'), False)
abaa.tag_object_of(('*', 'seda_creating_application_name', '*'), False)
abaa.tag_subject_of(('*', 'seda_creating_application_version', '*'), False)
abaa.tag_object_of(('*', 'seda_creating_application_version', '*'), False)
abaa.tag_subject_of(('*', 'seda_date_created_by_application', '*'), False)
abaa.tag_object_of(('*', 'seda_date_created_by_application', '*'), False)
abaa.tag_subject_of(('*', 'seda_creating_os', '*'), False)
abaa.tag_object_of(('*', 'seda_creating_os', '*'), False)
abaa.tag_subject_of(('*', 'seda_creating_os_version', '*'), False)
abaa.tag_object_of(('*', 'seda_creating_os_version', '*'), False)
abaa.tag_subject_of(('*', 'seda_last_modified', '*'), False)
abaa.tag_object_of(('*', 'seda_last_modified', '*'), False)
abaa.tag_subject_of(('*', 'seda_width', '*'), False)
abaa.tag_object_of(('*', 'seda_width', '*'), False)
abaa.tag_subject_of(('*', 'seda_height', '*'), False)
abaa.tag_object_of(('*', 'seda_height', '*'), False)
abaa.tag_subject_of(('*', 'seda_depth', '*'), False)
abaa.tag_object_of(('*', 'seda_depth', '*'), False)
abaa.tag_subject_of(('*', 'seda_shape', '*'), False)
abaa.tag_object_of(('*', 'seda_shape', '*'), False)
abaa.tag_subject_of(('*', 'seda_diameter', '*'), False)
abaa.tag_object_of(('*', 'seda_diameter', '*'), False)
abaa.tag_subject_of(('*', 'seda_length', '*'), False)
abaa.tag_object_of(('*', 'seda_length', '*'), False)
abaa.tag_subject_of(('*', 'seda_thickness', '*'), False)
abaa.tag_object_of(('*', 'seda_thickness', '*'), False)
abaa.tag_subject_of(('*', 'seda_weight', '*'), False)
abaa.tag_object_of(('*', 'seda_weight', '*'), False)
abaa.tag_subject_of(('*', 'seda_number_of_page', '*'), False)
abaa.tag_object_of(('*', 'seda_number_of_page', '*'), False)
abaa.tag_subject_of(('*', 'seda_archive_unit_ref_id_from', '*'), False)
abaa.tag_object_of(('*', 'seda_archive_unit_ref_id_from', '*'), False)
abaa.tag_object_of(('*', 'seda_archive_unit_ref_id_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_archive_unit_ref_id_to', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_alt_archive_unit_archive_unit_ref_id_management', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_alt_archive_unit_archive_unit_ref_id_management', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_storage_rule_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_storage_rule_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_storage_rule_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_storage_rule_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_final_action', '*'), False)
abaa.tag_subject_of(('*', 'seda_final_action', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_appraisal_rule_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_appraisal_rule_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_appraisal_rule_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_appraisal_rule_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_access_rule_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_access_rule_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_access_rule_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_access_rule_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_dissemination_rule_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_dissemination_rule_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_dissemination_rule_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_dissemination_rule_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_reuse_rule_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_reuse_rule_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_reuse_rule_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_reuse_rule_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_seq_classification_rule_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_seq_classification_rule_rule', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_classification_rule_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_classification_rule_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_classification_level', '*'), False)
abaa.tag_subject_of(('*', 'seda_classification_level', '*'), False)
abaa.tag_subject_of(('*', 'seda_classification_reassessing_date', '*'), False)
abaa.tag_object_of(('*', 'seda_classification_reassessing_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_need_reassessing_authorization', '*'), False)
abaa.tag_object_of(('*', 'seda_need_reassessing_authorization', '*'), False)
abaa.tag_subject_of(('*', 'seda_data_object_reference', '*'), False)
abaa.tag_object_of(('*', 'seda_data_object_reference', '*'), False)
abaa.tag_object_of(('*', 'seda_unit', '*'), False)
abaa.tag_subject_of(('*', 'seda_unit', '*'), False)
abaa.tag_object_of(('*', 'seda_description_level', '*'), False)
abaa.tag_subject_of(('*', 'seda_description_level', '*'), False)
abaa.tag_subject_of(('*', 'seda_title', '*'), False)
abaa.tag_object_of(('*', 'seda_title', '*'), False)
abaa.tag_subject_of(('*', 'seda_file_plan_position', '*'), False)
abaa.tag_object_of(('*', 'seda_file_plan_position', '*'), False)
abaa.tag_subject_of(('*', 'seda_system_id', '*'), False)
abaa.tag_object_of(('*', 'seda_system_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_originating_system_id', '*'), False)
abaa.tag_object_of(('*', 'seda_originating_system_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_archival_agency_archive_unit_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_archival_agency_archive_unit_identifier', '*'), False)
abaa.tag_subject_of(('*', 'seda_originating_agency_archive_unit_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_originating_agency_archive_unit_identifier', '*'), False)
abaa.tag_subject_of(('*', 'seda_transferring_agency_archive_unit_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_transferring_agency_archive_unit_identifier', '*'), False)
abaa.tag_subject_of(('*', 'seda_description', '*'), False)
abaa.tag_object_of(('*', 'seda_description', '*'), False)
abaa.tag_subject_of(('*', 'seda_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_document_type', '*'), False)
abaa.tag_object_of(('*', 'seda_document_type', '*'), False)
abaa.tag_subject_of(('*', 'seda_language_from', '*'), False)
abaa.tag_object_of(('*', 'seda_language_from', '*'), False)
abaa.tag_object_of(('*', 'seda_language_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_language_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_description_language_from', '*'), False)
abaa.tag_object_of(('*', 'seda_description_language_from', '*'), False)
abaa.tag_object_of(('*', 'seda_description_language_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_description_language_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_status', '*'), False)
abaa.tag_object_of(('*', 'seda_status', '*'), False)
abaa.tag_subject_of(('*', 'seda_version', '*'), False)
abaa.tag_object_of(('*', 'seda_version', '*'), False)
abaa.tag_subject_of(('*', 'seda_tag', '*'), False)
abaa.tag_object_of(('*', 'seda_tag', '*'), False)
abaa.tag_subject_of(('*', 'seda_keyword', '*'), False)
abaa.tag_object_of(('*', 'seda_keyword', '*'), False)
abaa.tag_subject_of(('*', 'seda_originating_agency_from', '*'), False)
abaa.tag_object_of(('*', 'seda_originating_agency_from', '*'), False)
abaa.tag_object_of(('*', 'seda_originating_agency_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_originating_agency_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_submission_agency_from', '*'), False)
abaa.tag_object_of(('*', 'seda_submission_agency_from', '*'), False)
abaa.tag_object_of(('*', 'seda_submission_agency_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_submission_agency_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_authorized_agent_from', '*'), False)
abaa.tag_object_of(('*', 'seda_authorized_agent_from', '*'), False)
abaa.tag_object_of(('*', 'seda_authorized_agent_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_authorized_agent_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_writer_from', '*'), False)
abaa.tag_object_of(('*', 'seda_writer_from', '*'), False)
abaa.tag_object_of(('*', 'seda_writer_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_writer_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_addressee_from', '*'), False)
abaa.tag_object_of(('*', 'seda_addressee_from', '*'), False)
abaa.tag_object_of(('*', 'seda_addressee_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_addressee_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_recipient_from', '*'), False)
abaa.tag_object_of(('*', 'seda_recipient_from', '*'), False)
abaa.tag_object_of(('*', 'seda_recipient_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_recipient_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_source', '*'), False)
abaa.tag_object_of(('*', 'seda_source', '*'), False)
abaa.tag_subject_of(('*', 'seda_created_date', '*'), False)
abaa.tag_object_of(('*', 'seda_created_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_transacted_date', '*'), False)
abaa.tag_object_of(('*', 'seda_transacted_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_acquired_date', '*'), False)
abaa.tag_object_of(('*', 'seda_acquired_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_sent_date', '*'), False)
abaa.tag_object_of(('*', 'seda_sent_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_received_date', '*'), False)
abaa.tag_object_of(('*', 'seda_received_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_registered_date', '*'), False)
abaa.tag_object_of(('*', 'seda_registered_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_start_date', '*'), False)
abaa.tag_object_of(('*', 'seda_start_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_end_date', '*'), False)
abaa.tag_object_of(('*', 'seda_end_date', '*'), False)
abaa.tag_subject_of(('*', 'seda_event', '*'), False)
abaa.tag_object_of(('*', 'seda_event', '*'), False)
abaa.tag_object_of(('*', 'seda_data_object_reference_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_data_object_reference_id', '*'), False)
abaa.tag_object_of(('*', 'seda_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_rule', '*'), False)
abaa.tag_subject_of(('*', 'seda_prevent_inheritance', '*'), False)
abaa.tag_object_of(('*', 'seda_prevent_inheritance', '*'), False)
abaa.tag_subject_of(('*', 'seda_ref_non_rule_id_from', '*'), False)
abaa.tag_object_of(('*', 'seda_ref_non_rule_id_from', '*'), False)
abaa.tag_object_of(('*', 'seda_ref_non_rule_id_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_ref_non_rule_id_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_custodial_history_item', '*'), False)
abaa.tag_object_of(('*', 'seda_custodial_history_item', '*'), False)
abaa.tag_subject_of(('*', 'seda_custodial_history_file', '*'), False)
abaa.tag_object_of(('*', 'seda_custodial_history_file', '*'), False)
abaa.tag_subject_of(('*', 'seda_keyword_reference_from', '*'), False)
abaa.tag_object_of(('*', 'seda_keyword_reference_from', '*'), False)
abaa.tag_object_of(('*', 'seda_keyword_reference_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_keyword_reference_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_keyword_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_keyword_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_keyword_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_keyword_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_spatial', '*'), False)
abaa.tag_object_of(('*', 'seda_spatial', '*'), False)
abaa.tag_subject_of(('*', 'seda_temporal', '*'), False)
abaa.tag_object_of(('*', 'seda_temporal', '*'), False)
abaa.tag_subject_of(('*', 'seda_juridictional', '*'), False)
abaa.tag_object_of(('*', 'seda_juridictional', '*'), False)
abaa.tag_subject_of(('*', 'seda_is_version_of', '*'), False)
abaa.tag_object_of(('*', 'seda_is_version_of', '*'), False)
abaa.tag_subject_of(('*', 'seda_replaces', '*'), False)
abaa.tag_object_of(('*', 'seda_replaces', '*'), False)
abaa.tag_subject_of(('*', 'seda_requires', '*'), False)
abaa.tag_object_of(('*', 'seda_requires', '*'), False)
abaa.tag_subject_of(('*', 'seda_is_part_of', '*'), False)
abaa.tag_object_of(('*', 'seda_is_part_of', '*'), False)
abaa.tag_subject_of(('*', 'seda_references', '*'), False)
abaa.tag_object_of(('*', 'seda_references', '*'), False)
abaa.tag_subject_of(('*', 'seda_event_identifier', '*'), False)
abaa.tag_object_of(('*', 'seda_event_identifier', '*'), False)
abaa.tag_subject_of(('*', 'seda_event_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_event_type_from', '*'), False)
abaa.tag_object_of(('*', 'seda_event_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_event_type_to', '*'), False)
abaa.tag_subject_of(('*', 'seda_event_detail', '*'), False)
abaa.tag_object_of(('*', 'seda_event_detail', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_version_id', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_version_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_altitude', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_altitude', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_altitude_ref', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_altitude_ref', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_latitude', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_latitude', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_latitude_ref', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_latitude_ref', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_longitude', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_longitude', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_longitude_ref', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_longitude_ref', '*'), False)
abaa.tag_subject_of(('*', 'seda_gps_date_stamp', '*'), False)
abaa.tag_object_of(('*', 'seda_gps_date_stamp', '*'), False)
abaa.tag_subject_of(('*', 'seda_when', '*'), False)
abaa.tag_object_of(('*', 'seda_when', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_is_version_of_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_is_version_of_archive_unit_ref_id', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_replaces_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_replaces_archive_unit_ref_id', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_requires_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_requires_archive_unit_ref_id', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_is_part_of_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_is_part_of_archive_unit_ref_id', '*'), False)
abaa.tag_object_of(('*', 'seda_alt_references_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_alt_references_archive_unit_ref_id', '*'), False)
abaa.tag_subject_of(('*', 'seda_repository_archive_unit_pid', '*'), False)
abaa.tag_object_of(('*', 'seda_repository_archive_unit_pid', '*'), False)
abaa.tag_subject_of(('*', 'seda_repository_object_pid', '*'), False)
abaa.tag_object_of(('*', 'seda_repository_object_pid', '*'), False)


affk = uicfg.autoform_field_kwargs
affk.tag_subject_of(('*', 'comment', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'archival_agreement', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_mime_type_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_encoding_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_file_format_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_data_object_version_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_storage_rule_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_access_rule_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_classification_rule_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'seda_relationship_code_list_version_to', '*'), {'label': 'value'})
affk.tag_subject_of(('*', 'filename', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'compressed', '*'), {'allow_none': True})
affk.tag_subject_of(('*', 'service_level', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'originating_agency_identifier', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'submission_agency_identifier', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'classification_owner', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'need_authorization', '*'), {'allow_none': True})
affk.tag_subject_of(('*', 'format_litteral', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'creating_application_name', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'creating_application_version', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'creating_os', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'creating_os_version', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'need_reassessing_authorization', '*'), {'allow_none': True})
affk.tag_subject_of(('*', 'title', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'file_plan_position', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'archival_agency_archive_unit_identifier', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'originating_agency_archive_unit_identifier', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'transferring_agency_archive_unit_identifier', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'description', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'document_type', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'status', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'version', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'tag', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'keyword_content', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'source', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'prevent_inheritance', '*'), {'allow_none': True})
affk.tag_subject_of(('*', 'custodial_history_item', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'spatial', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'temporal', '*'), {'widget': fw.TextInput({'size': 80})})
affk.tag_subject_of(('*', 'juridictional', '*'), {'widget': fw.TextInput({'size': 80})})


afs = uicfg.autoform_section
afs.tag_subject_of(('*', 'seda_comment', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_comment', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_signature', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_signature', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_archival_agreement', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_archival_agreement', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_related_transfer_reference', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_related_transfer_reference', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_transfer_request_reply_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_transfer_request_reply_identifier', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_archival_agency', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_archival_agency', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_transferring_agency', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_transferring_agency', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_mime_type_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_mime_type_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_mime_type_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_mime_type_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_encoding_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_encoding_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_encoding_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_encoding_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_file_format_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_file_format_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_file_format_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_file_format_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_data_object_version_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_data_object_version_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_data_object_version_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_data_object_version_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_storage_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_storage_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_storage_rule_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_storage_rule_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_access_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_access_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_access_rule_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_access_rule_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_classification_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_classification_rule_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_classification_rule_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_classification_rule_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_relationship_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_relationship_code_list_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_relationship_code_list_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_relationship_code_list_version_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_binary_data_object', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_binary_data_object', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_physical_data_object', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_physical_data_object', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_relationship', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_relationship', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_data_object_version_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_data_object_version_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_data_object_version_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_data_object_version_to', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_alt_binary_data_object_attachment', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_binary_data_object_attachment', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_compressed', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_compressed', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_archive_unit', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_archive_unit', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_service_level', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_service_level', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_acquisition_information_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_acquisition_information_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_acquisition_information_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_acquisition_information_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_legal_status_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_legal_status_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_legal_status_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_legal_status_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_originating_agency_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_originating_agency_identifier', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_submission_agency_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_submission_agency_identifier', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_storage_rule', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_storage_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_appraisal_rule', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_appraisal_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_access_rule', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_access_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_dissemination_rule', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_dissemination_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_reuse_rule', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_reuse_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_classification_rule', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_classification_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_need_authorization', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_need_authorization', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_alt_archive_unit_archive_unit_ref_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_archive_unit_archive_unit_ref_id', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_type_relationship', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_type_relationship', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_target', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_target', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_attachment', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_attachment', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_uri', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_uri', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_algorithm', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_algorithm', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_format_litteral', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_format_litteral', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_mime_type_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_mime_type_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_mime_type_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_mime_type_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_format_id_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_format_id_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_format_id_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_format_id_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_encoding_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_encoding_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_encoding_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_encoding_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_creating_application_name', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_creating_application_name', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_creating_application_version', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_creating_application_version', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_date_created_by_application', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_date_created_by_application', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_creating_os', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_creating_os', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_creating_os_version', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_creating_os_version', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_last_modified', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_last_modified', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_width', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_width', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_height', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_height', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_depth', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_depth', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_shape', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_shape', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_diameter', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_diameter', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_length', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_length', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_thickness', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_thickness', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_weight', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_weight', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_number_of_page', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_number_of_page', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_archive_unit_ref_id_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_archive_unit_ref_id_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_archive_unit_ref_id_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_archive_unit_ref_id_to', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_seq_alt_archive_unit_archive_unit_ref_id_management', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_alt_archive_unit_archive_unit_ref_id_management', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_seq_storage_rule_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_storage_rule_rule', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_storage_rule_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_storage_rule_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_final_action', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_final_action', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_seq_appraisal_rule_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_appraisal_rule_rule', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_appraisal_rule_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_appraisal_rule_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_seq_access_rule_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_access_rule_rule', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_access_rule_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_access_rule_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_seq_dissemination_rule_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_dissemination_rule_rule', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_dissemination_rule_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_dissemination_rule_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_seq_reuse_rule_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_reuse_rule_rule', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_reuse_rule_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_reuse_rule_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_seq_classification_rule_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_seq_classification_rule_rule', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_classification_rule_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_classification_rule_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_classification_level', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_classification_level', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_classification_reassessing_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_classification_reassessing_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_need_reassessing_authorization', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_need_reassessing_authorization', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_data_object_reference', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_data_object_reference', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_unit', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_unit', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_description_level', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_description_level', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_title', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_title', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_file_plan_position', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_file_plan_position', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_system_id', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_system_id', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_originating_system_id', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_originating_system_id', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_archival_agency_archive_unit_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_archival_agency_archive_unit_identifier', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_originating_agency_archive_unit_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_originating_agency_archive_unit_identifier', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_transferring_agency_archive_unit_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_transferring_agency_archive_unit_identifier', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_description', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_description', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_type_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_type_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_type_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_type_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_document_type', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_document_type', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_language_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_language_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_language_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_language_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_description_language_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_description_language_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_description_language_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_description_language_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_status', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_status', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_version', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_version', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_tag', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_tag', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_keyword', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_keyword', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_originating_agency_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_originating_agency_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_originating_agency_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_originating_agency_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_submission_agency_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_submission_agency_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_submission_agency_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_submission_agency_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_authorized_agent_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_authorized_agent_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_authorized_agent_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_authorized_agent_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_writer_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_writer_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_writer_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_writer_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_addressee_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_addressee_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_addressee_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_addressee_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_recipient_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_recipient_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_recipient_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_recipient_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_source', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_source', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_created_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_created_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_transacted_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_transacted_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_acquired_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_acquired_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_sent_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_sent_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_received_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_received_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_registered_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_registered_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_start_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_start_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_end_date', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_end_date', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_event', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_event', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_data_object_reference_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_data_object_reference_id', '*'), 'main', 'attributes')
afs.tag_object_of(('*', 'seda_rule', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_rule', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_prevent_inheritance', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_prevent_inheritance', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_ref_non_rule_id_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_ref_non_rule_id_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_ref_non_rule_id_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_ref_non_rule_id_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_custodial_history_item', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_custodial_history_item', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_custodial_history_file', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_custodial_history_file', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_keyword_reference_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_keyword_reference_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_keyword_reference_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_keyword_reference_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_keyword_type_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_keyword_type_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_keyword_type_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_keyword_type_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_spatial', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_spatial', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_temporal', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_temporal', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_juridictional', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_juridictional', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_is_version_of', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_is_version_of', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_replaces', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_replaces', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_requires', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_requires', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_is_part_of', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_is_part_of', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_references', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_references', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_event_identifier', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_event_identifier', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_event_type_from', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_event_type_from', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_event_type_to', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_event_type_to', '*'), 'main', 'attributes')
afs.tag_subject_of(('*', 'seda_event_detail', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_event_detail', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_gps_version_id', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_version_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_altitude', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_altitude', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_altitude_ref', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_altitude_ref', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_latitude', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_latitude', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_latitude_ref', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_latitude_ref', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_longitude', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_longitude', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_longitude_ref', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_longitude_ref', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_gps_date_stamp', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_gps_date_stamp', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_when', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_when', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_is_version_of_archive_unit_ref_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_is_version_of_archive_unit_ref_id', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_replaces_archive_unit_ref_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_replaces_archive_unit_ref_id', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_requires_archive_unit_ref_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_requires_archive_unit_ref_id', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_is_part_of_archive_unit_ref_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_is_part_of_archive_unit_ref_id', '*'), 'main', 'inlined')
afs.tag_object_of(('*', 'seda_alt_references_archive_unit_ref_id', '*'), 'main', 'hidden')
afs.tag_subject_of(('*', 'seda_alt_references_archive_unit_ref_id', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_repository_archive_unit_pid', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_repository_archive_unit_pid', '*'), 'main', 'inlined')
afs.tag_subject_of(('*', 'seda_repository_object_pid', '*'), 'main', 'hidden')
afs.tag_object_of(('*', 'seda_repository_object_pid', '*'), 'main', 'inlined')


pvs = uicfg.primaryview_section
pvs.tag_subject_of(('*', 'seda_related_transfer_reference', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_related_transfer_reference', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_archival_agency', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_transferring_agency', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_mime_type_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_mime_type_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_mime_type_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_encoding_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_encoding_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_encoding_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_file_format_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_file_format_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_file_format_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_data_object_version_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_data_object_version_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_data_object_version_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_storage_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_storage_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_storage_rule_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_access_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_access_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_access_rule_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_classification_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_classification_rule_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_classification_rule_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_relationship_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_relationship_code_list_version_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_relationship_code_list_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_binary_data_object', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_binary_data_object', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_physical_data_object', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_physical_data_object', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_relationship', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_relationship', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_data_object_version_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_archive_unit', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_archive_unit', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_acquisition_information_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_legal_status_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_storage_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_storage_rule', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_appraisal_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_appraisal_rule', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_access_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_access_rule', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_dissemination_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_dissemination_rule', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_reuse_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_reuse_rule', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_classification_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_classification_rule', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_need_authorization', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_need_authorization', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_type_relationship', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_algorithm', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_format_litteral', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_format_litteral', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_mime_type_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_mime_type_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_mime_type_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_format_id_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_format_id_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_format_id_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_encoding_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_encoding_from', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_encoding_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_creating_application_name', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_creating_application_name', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_creating_application_version', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_creating_application_version', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_date_created_by_application', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_date_created_by_application', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_creating_os', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_creating_os', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_creating_os_version', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_creating_os_version', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_last_modified', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_last_modified', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_width', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_width', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_height', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_height', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_depth', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_depth', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_shape', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_shape', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_diameter', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_diameter', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_length', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_length', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_thickness', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_thickness', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_weight', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_weight', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_number_of_page', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_number_of_page', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_final_action', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_classification_level', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_unit', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_description_level', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_type_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_language_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_description_language_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_originating_agency_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_submission_agency_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_authorized_agent_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_writer_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_addressee_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_recipient_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_rule', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_ref_non_rule_id_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_custodial_history_item', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_custodial_history_item', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_custodial_history_file', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_custodial_history_file', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_keyword_reference_to', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_keyword_type_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_spatial', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_spatial', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_temporal', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_temporal', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_juridictional', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_juridictional', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_is_version_of', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_is_version_of', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_replaces', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_replaces', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_requires', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_requires', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_is_part_of', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_is_part_of', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_references', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_references', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_event_type_to', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_version_id', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_version_id', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_altitude', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_altitude', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_altitude_ref', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_altitude_ref', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_latitude', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_latitude', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_latitude_ref', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_latitude_ref', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_longitude', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_longitude', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_longitude_ref', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_longitude_ref', '*'), 'hidden')
pvs.tag_subject_of(('*', 'seda_gps_date_stamp', '*'), 'hidden')
pvs.tag_object_of(('*', 'seda_gps_date_stamp', '*'), 'hidden')


rec = uicfg.reledit_ctrl
rec.tag_subject_of(('*', 'comment', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_comment', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_signature', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'archival_agreement', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_archival_agreement', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_transfer_request_reply_identifier', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_archival_agency', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_transferring_agency', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_message_digest_algorithm_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_message_digest_algorithm_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_mime_type_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_mime_type_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_encoding_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_encoding_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_file_format_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_file_format_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_compression_algorithm_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_compression_algorithm_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_data_object_version_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_data_object_version_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_storage_rule_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_storage_rule_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_appraisal_rule_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_appraisal_rule_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_access_rule_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_access_rule_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_dissemination_rule_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_dissemination_rule_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_reuse_rule_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_reuse_rule_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_classification_rule_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_classification_rule_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_acquisition_information_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_acquisition_information_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_relationship_code_list_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_relationship_code_list_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'filename', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_data_object_version_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_data_object_version_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_alt_binary_data_object_attachment', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'compressed', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_compressed', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'service_level', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_service_level', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_acquisition_information_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_acquisition_information_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_legal_status_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_legal_status_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'originating_agency_identifier', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_originating_agency_identifier', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'submission_agency_identifier', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_submission_agency_identifier', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_storage_rule', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_appraisal_rule', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_access_rule', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_dissemination_rule', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_reuse_rule', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'classification_owner', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_classification_rule', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'need_authorization', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_need_authorization', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_archive_unit_archive_unit_ref_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_type_relationship', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_target', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_attachment', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_uri', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_algorithm', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'format_litteral', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_format_litteral', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_mime_type_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_mime_type_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_format_id_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_format_id_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_encoding_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_encoding_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'creating_application_name', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_creating_application_name', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'creating_application_version', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_creating_application_version', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_date_created_by_application', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'creating_os', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_creating_os', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'creating_os_version', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_creating_os_version', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_last_modified', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_width', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_height', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_depth', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_shape', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_diameter', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_length', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_thickness', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_weight', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_number_of_page', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_archive_unit_ref_id_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_archive_unit_ref_id_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_seq_alt_archive_unit_archive_unit_ref_id_management', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_storage_rule_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_final_action', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_alt_appraisal_rule_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_access_rule_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_dissemination_rule_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_reuse_rule_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_classification_rule_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_classification_level', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_classification_reassessing_date', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'need_reassessing_authorization', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_need_reassessing_authorization', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_unit', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_description_level', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'title', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_title', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'file_plan_position', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_file_plan_position', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_system_id', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_originating_system_id', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'archival_agency_archive_unit_identifier', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_archival_agency_archive_unit_identifier', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'originating_agency_archive_unit_identifier', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_originating_agency_archive_unit_identifier', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'transferring_agency_archive_unit_identifier', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_transferring_agency_archive_unit_identifier', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'description', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_description', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_type_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_type_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'document_type', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_document_type', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_language_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_language_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_description_language_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_description_language_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'status', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_status', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'version', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_version', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'tag', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'keyword_content', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_originating_agency_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_originating_agency_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_submission_agency_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_submission_agency_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_authorized_agent_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_authorized_agent_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_writer_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_addressee_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_recipient_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'source', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_source', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_created_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_transacted_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_acquired_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_sent_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_received_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_registered_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_start_date', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_end_date', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_data_object_reference_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_rule', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'prevent_inheritance', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_prevent_inheritance', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_ref_non_rule_id_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'custodial_history_item', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_custodial_history_file', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_keyword_reference_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_keyword_reference_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_keyword_type_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_keyword_type_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'spatial', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'temporal', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'juridictional', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_event_identifier', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_event_type_from', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_event_type_to', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_event_detail', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_version_id', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_altitude', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_altitude_ref', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_latitude', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_latitude_ref', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_longitude', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_longitude_ref', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_gps_date_stamp', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_when', '*'), {'novalue_label': ' '})
rec.tag_subject_of(('*', 'seda_alt_is_version_of_archive_unit_ref_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_alt_replaces_archive_unit_ref_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_alt_requires_archive_unit_ref_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_alt_is_part_of_archive_unit_ref_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_subject_of(('*', 'seda_alt_references_archive_unit_ref_id', '*'), {'novalue_label': '<no value specified>'})
rec.tag_object_of(('*', 'seda_repository_archive_unit_pid', '*'), {'novalue_label': ' '})
rec.tag_object_of(('*', 'seda_repository_object_pid', '*'), {'novalue_label': ' '})
pvds = uicfg.primaryview_display_ctrl
affk.set_fields_order('SEDAArchiveTransfer', ['title', 'user_annotation'])
pvds.set_fields_order('SEDAArchiveTransfer', ['title', 'user_annotation'])
affk.set_fields_order('SEDAComment', ['user_cardinality', 'comment', 'user_annotation'])
pvds.set_fields_order('SEDAComment', ['user_cardinality', 'comment', 'user_annotation'])
affk.set_fields_order('SEDAArchivalAgreement', ['user_cardinality', 'archival_agreement', 'user_annotation'])
pvds.set_fields_order('SEDAArchivalAgreement', ['user_cardinality', 'archival_agreement', 'user_annotation'])
affk.set_fields_order('SEDABinaryDataObject', ['filename', 'user_cardinality', 'user_annotation'])
pvds.set_fields_order('SEDABinaryDataObject', ['filename', 'user_cardinality', 'user_annotation'])
affk.set_fields_order('SEDAPhysicalDataObject', ['user_cardinality', 'user_annotation'])
pvds.set_fields_order('SEDAPhysicalDataObject', ['user_cardinality', 'user_annotation'])
affk.set_fields_order('SEDACompressed', ['user_cardinality', 'compressed', 'user_annotation'])
pvds.set_fields_order('SEDACompressed', ['user_cardinality', 'compressed', 'user_annotation'])
affk.set_fields_order('SEDAArchiveUnit', ['user_cardinality', 'user_annotation'])
pvds.set_fields_order('SEDAArchiveUnit', ['user_cardinality', 'user_annotation'])
affk.set_fields_order('SEDAServiceLevel', ['user_cardinality', 'service_level', 'user_annotation'])
pvds.set_fields_order('SEDAServiceLevel', ['user_cardinality', 'service_level', 'user_annotation'])
affk.set_fields_order('SEDAOriginatingAgencyIdentifier', ['user_cardinality', 'originating_agency_identifier', 'user_annotation'])
pvds.set_fields_order('SEDAOriginatingAgencyIdentifier', ['user_cardinality', 'originating_agency_identifier', 'user_annotation'])
affk.set_fields_order('SEDASubmissionAgencyIdentifier', ['user_cardinality', 'submission_agency_identifier', 'user_annotation'])
pvds.set_fields_order('SEDASubmissionAgencyIdentifier', ['user_cardinality', 'submission_agency_identifier', 'user_annotation'])
affk.set_fields_order('SEDAClassificationRule', ['user_cardinality', 'classification_owner', 'user_annotation'])
pvds.set_fields_order('SEDAClassificationRule', ['user_cardinality', 'classification_owner', 'user_annotation'])
affk.set_fields_order('SEDANeedAuthorization', ['user_cardinality', 'need_authorization', 'user_annotation'])
pvds.set_fields_order('SEDANeedAuthorization', ['user_cardinality', 'need_authorization', 'user_annotation'])
affk.set_fields_order('SEDAFormatLitteral', ['user_cardinality', 'format_litteral', 'user_annotation'])
pvds.set_fields_order('SEDAFormatLitteral', ['user_cardinality', 'format_litteral', 'user_annotation'])
affk.set_fields_order('SEDACreatingApplicationName', ['user_cardinality', 'creating_application_name', 'user_annotation'])
pvds.set_fields_order('SEDACreatingApplicationName', ['user_cardinality', 'creating_application_name', 'user_annotation'])
affk.set_fields_order('SEDACreatingApplicationVersion', ['user_cardinality', 'creating_application_version', 'user_annotation'])
pvds.set_fields_order('SEDACreatingApplicationVersion', ['user_cardinality', 'creating_application_version', 'user_annotation'])
affk.set_fields_order('SEDACreatingOs', ['user_cardinality', 'creating_os', 'user_annotation'])
pvds.set_fields_order('SEDACreatingOs', ['user_cardinality', 'creating_os', 'user_annotation'])
affk.set_fields_order('SEDACreatingOsVersion', ['user_cardinality', 'creating_os_version', 'user_annotation'])
pvds.set_fields_order('SEDACreatingOsVersion', ['user_cardinality', 'creating_os_version', 'user_annotation'])
affk.set_fields_order('SEDANeedReassessingAuthorization', ['user_cardinality', 'need_reassessing_authorization', 'user_annotation'])
pvds.set_fields_order('SEDANeedReassessingAuthorization', ['user_cardinality', 'need_reassessing_authorization', 'user_annotation'])
affk.set_fields_order('SEDATitle', ['user_cardinality', 'title', 'user_annotation'])
pvds.set_fields_order('SEDATitle', ['user_cardinality', 'title', 'user_annotation'])
affk.set_fields_order('SEDAFilePlanPosition', ['user_cardinality', 'file_plan_position', 'user_annotation'])
pvds.set_fields_order('SEDAFilePlanPosition', ['user_cardinality', 'file_plan_position', 'user_annotation'])
affk.set_fields_order('SEDAArchivalAgencyArchiveUnitIdentifier', ['user_cardinality', 'archival_agency_archive_unit_identifier', 'user_annotation'])
pvds.set_fields_order('SEDAArchivalAgencyArchiveUnitIdentifier', ['user_cardinality', 'archival_agency_archive_unit_identifier', 'user_annotation'])
affk.set_fields_order('SEDAOriginatingAgencyArchiveUnitIdentifier', ['user_cardinality', 'originating_agency_archive_unit_identifier', 'user_annotation'])
pvds.set_fields_order('SEDAOriginatingAgencyArchiveUnitIdentifier', ['user_cardinality', 'originating_agency_archive_unit_identifier', 'user_annotation'])
affk.set_fields_order('SEDATransferringAgencyArchiveUnitIdentifier', ['user_cardinality', 'transferring_agency_archive_unit_identifier', 'user_annotation'])
pvds.set_fields_order('SEDATransferringAgencyArchiveUnitIdentifier', ['user_cardinality', 'transferring_agency_archive_unit_identifier', 'user_annotation'])
affk.set_fields_order('SEDADescription', ['user_cardinality', 'description', 'user_annotation'])
pvds.set_fields_order('SEDADescription', ['user_cardinality', 'description', 'user_annotation'])
affk.set_fields_order('SEDADocumentType', ['user_cardinality', 'document_type', 'user_annotation'])
pvds.set_fields_order('SEDADocumentType', ['user_cardinality', 'document_type', 'user_annotation'])
affk.set_fields_order('SEDAStatus', ['user_cardinality', 'status', 'user_annotation'])
pvds.set_fields_order('SEDAStatus', ['user_cardinality', 'status', 'user_annotation'])
affk.set_fields_order('SEDAVersion', ['user_cardinality', 'version', 'user_annotation'])
pvds.set_fields_order('SEDAVersion', ['user_cardinality', 'version', 'user_annotation'])
affk.set_fields_order('SEDATag', ['user_cardinality', 'tag', 'user_annotation'])
pvds.set_fields_order('SEDATag', ['user_cardinality', 'tag', 'user_annotation'])
affk.set_fields_order('SEDAKeyword', ['user_cardinality', 'keyword_content', 'user_annotation'])
pvds.set_fields_order('SEDAKeyword', ['user_cardinality', 'keyword_content', 'user_annotation'])
affk.set_fields_order('SEDASource', ['user_cardinality', 'source', 'user_annotation'])
pvds.set_fields_order('SEDASource', ['user_cardinality', 'source', 'user_annotation'])
affk.set_fields_order('SEDACustodialHistoryItem', ['user_cardinality', 'custodial_history_item', 'user_annotation'])
pvds.set_fields_order('SEDACustodialHistoryItem', ['user_cardinality', 'custodial_history_item', 'user_annotation'])
affk.set_fields_order('SEDASpatial', ['user_cardinality', 'spatial', 'user_annotation'])
pvds.set_fields_order('SEDASpatial', ['user_cardinality', 'spatial', 'user_annotation'])
affk.set_fields_order('SEDATemporal', ['user_cardinality', 'temporal', 'user_annotation'])
pvds.set_fields_order('SEDATemporal', ['user_cardinality', 'temporal', 'user_annotation'])
affk.set_fields_order('SEDAJuridictional', ['user_cardinality', 'juridictional', 'user_annotation'])
pvds.set_fields_order('SEDAJuridictional', ['user_cardinality', 'juridictional', 'user_annotation'])



# copyright 2016-2017 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
# contact http://www.logilab.fr -- mailto:contact@logilab.fr
#
# This program is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 2.1 of the License, or (at your option)
# any later version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
"""cubicweb-seda views for ArchiveUnit"""

from cubicweb import _
from cubicweb.predicates import adaptable, is_instance
from cubicweb.web import component

from ..entities import simplified_profile, component_unit
from . import jqtree


class ProfileTreeComponent(component.EntityCtxComponent):
    """Display the whole profile tree."""
    __regid__ = 'seda.tree'
    __select__ = (component.EntityCtxComponent.__select__
                  & adaptable('ITreeBase'))
    context = 'left'
    order = -1
    title = _('SEDA profile tree')

    def render_body(self, w):
        self._cw.add_css('cubes.jqtree.css')
        self.entity.view('jqtree.treeview', w=w)


class UnitTreeComponent(ProfileTreeComponent):
    __select__ = ProfileTreeComponent.__select__ & component_unit()
    title = _('Archive unit component tree')


class ArchiveTransferIJQTreeAdapter(jqtree.IJQTreeAdapter):
    __select__ = (jqtree.IJQTreeAdapter.__select__
                  & is_instance('SEDAArchiveTransfer'))

    def maybe_parent_of(self):
        return ['SEDAArchiveUnit',
                'SEDAPhysicalDataObject', 'SEDABinaryDataObject']


class SimplifiedArchiveTransferIJQTreeAdapter(ArchiveTransferIJQTreeAdapter):
    __select__ = ArchiveTransferIJQTreeAdapter.__select__ & simplified_profile()

    def maybe_parent_of(self):
        return ['SEDAArchiveUnit']


class ArchiveUnitIJQTreeAdapter(jqtree.IJQTreeAdapter):
    __select__ = (jqtree.IJQTreeAdapter.__select__
                  & is_instance('SEDAArchiveUnit'))

    def maybe_parent_of(self):
        return [] if self.entity.is_archive_unit_ref else ['SEDAArchiveUnit']

    def maybe_moved(self):
        return True

    def reparent(self, peid):
        parent = self._cw.entity_from_eid(peid)
        if parent.cw_etype == 'SEDAArchiveUnit':
            parent = parent.first_level_choice.content_sequence
        else:
            assert parent.cw_etype == 'SEDAArchiveTransfer', (
                'cannot re-parent to entity type {0}'.format(parent.cw_etype))
        rset = self._cw.execute(
            'SET X seda_archive_unit P WHERE X eid %(x)s, P eid %(p)s',
            {'x': self.entity.eid, 'p': parent.eid})
        return rset.rows


class SimplifiedArchiveUnitIJQTreeAdapter(ArchiveUnitIJQTreeAdapter):
    __select__ = ArchiveUnitIJQTreeAdapter.__select__ & simplified_profile()

    def maybe_parent_of(self):
        return [] if self.entity.is_archive_unit_ref else ['SEDAArchiveUnit',
                                                           'SEDABinaryDataObject']


class DataObjectIJQTreeAdapter(jqtree.IJQTreeAdapter):
    __select__ = (jqtree.IJQTreeAdapter.__select__
                  & is_instance('SEDABinaryDataObject', 'SEDAPhysicalDataObject'))

    def maybe_moved(self):
        return False


class SimplifiedBinaryDataObjectIJQTreeAdapter(jqtree.IJQTreeAdapter):
    __select__ = (jqtree.IJQTreeAdapter.__select__
                  & is_instance('SEDABinaryDataObject') & simplified_profile())
    rtype_to_archivetransfer = 'seda_binary_data_object'

    def maybe_moved(self):
        return True

    def reparent(self, peid):
        archunit = self._cw.entity_from_eid(peid)
        parent = archunit.first_level_choice.content_sequence
        rset = self._cw.execute(
            'SET REF seda_data_object_reference SEQ WHERE'
            ' REF seda_data_object_reference_id X,'
            ' X eid %(x)s, SEQ eid %(seq)s',
            {'x': self.entity.eid, 'seq': parent.eid})
        return rset.rows
